---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run [command]
2. Do '....'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

<!-- Find the ti842py version by running `ti842py --version` in a terminal -->
**Desktop (please complete the following information):**
 - OS: [e.g. Manjaro Linux]
 - ti842py version: [e.g. 0.9.6]
 - Python version [e.g. 3.9.6]

**Additional context**
Add any other context about the problem here.
